
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.011.
use strict;
use warnings;

use Module::Build 0.4208;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.4208"
  },
  "configure_requires" => {
    "Module::Build" => "0.4208",
    "Module::Build::Version" => 0
  },
  "dist_abstract" => "common tests to check for copyright and license notices",
  "dist_author" => [
    "Alan Young <ayoung\@cpan.org>"
  ],
  "dist_name" => "Dist-Zilla-Plugin-Test-Legal",
  "dist_version" => "0.03",
  "license" => "perl",
  "module_name" => "Dist::Zilla::Plugin::Test::Legal",
  "recursive_test_files" => 1,
  "requires" => {
    "Dist::Zilla::Plugin::InlineFiles" => 0,
    "Moose" => 0,
    "namespace::autoclean" => 0,
    "perl" => "5.006",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "Carp" => 0,
    "ExtUtils::MakeMaker" => 0,
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Scalar::Util" => 0,
    "Test::CPAN::Meta::JSON" => 0,
    "Test::CheckDeps" => "0.010",
    "Test::CheckManifest" => 0,
    "Test::ConsistentVersion" => 0,
    "Test::DistManifest" => 0,
    "Test::HasVersion" => 0,
    "Test::MinimumVersion" => 0,
    "Test::More" => "0.94",
    "Test::NoSmartComments" => 0,
    "Test::Perl::Critic" => 0,
    "Test::Pod::Content" => 0,
    "Test::UseAllModules" => 0,
    "Test::Version" => 0
  }
);


my %fallback_build_requires = (
  "Carp" => 0,
  "ExtUtils::MakeMaker" => 0,
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.4208",
  "Scalar::Util" => 0,
  "Test::CPAN::Meta::JSON" => 0,
  "Test::CheckDeps" => "0.010",
  "Test::CheckManifest" => 0,
  "Test::ConsistentVersion" => 0,
  "Test::DistManifest" => 0,
  "Test::HasVersion" => 0,
  "Test::MinimumVersion" => 0,
  "Test::More" => "0.94",
  "Test::NoSmartComments" => 0,
  "Test::Perl::Critic" => 0,
  "Test::Pod::Content" => 0,
  "Test::UseAllModules" => 0,
  "Test::Version" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
